@@ -25,6 +25,9 @@
 #include <gtkmm/builder.h>
 #include <glom/dialog_progress_creating.h>
 #include <giomm/file.h>
+#include <glibmm/miscutils.h>
+#include <glibmm/markup.h>
+#include <glibmm/fileutils.h>
 
 namespace Glom
 {
@@ -69,15 +72,19 @@ void helper_get_glade_widget_derived_with_warning(const std::string& filename, c
   }
   catch(const Gtk::BuilderError& ex)
   {
-    std::cerr << ex.what() << std::endl;
+    std::cerr << G_STRFUNC << ": " << ex.what() << std::endl;
   }
   catch(const Glib::MarkupError& ex)
   {
-    std::cerr << ex.what() << std::endl;
+    std::cerr << G_STRFUNC << ": " << ex.what() << std::endl;
   }
   catch(const Glib::FileError& ex)
   {
-    std::cerr << ex.what() << std::endl;
+    std::cerr << G_STRFUNC << ": " << ex.what() << std::endl;
+  }
+  catch(const Glib::Error& ex)
+  {
+    std::cerr << G_STRFUNC << ": Exception of unexpected type: " << ex.what() << std::endl;
   }
 #else
   std::auto_ptr<Glib::Error> error;
@@ -92,13 +99,6 @@ void helper_get_glade_widget_derived_with_warning(const std::string& filename, c
   {
     refXml->get_widget_derived(id, widget);
   }
-
-  // Make sure that all windows have the Glom icon.
-  // TODO: Though shouldn't all transient windows have this by default,
-  // or should they even be visible in the task list? murrayc
-  Gtk::Window* window = dynamic_cast<Gtk::Window*>(widget);
-  if(window)
-    window->set_icon_name("glom");
 }
 
 template<class T_Widget>
