@@ -24,6 +24,8 @@
 #include <libglom/utils.h>
 #include <glibmm/i18n.h>
 
+#include <iostream>
+
 namespace Glom
 {
 
@@ -380,7 +382,7 @@ Glib::ustring Field::sql_find(const Gnome::Gda::Value& value) const
       if(value.is_null())
         return "''"; //We want to ignore the concept of NULL strings, and deal only with empty strings.
       else
-        return ("'%" + value.to_string() + "%'"); //Add single-quotes. TODO: Actually escape it.
+        return ("%" + value.to_string() + "%"); //TODO: Escape it before adding "%", but then prevent SqlBuilder from re-escaping it.
         
       break;
     }
@@ -396,7 +398,7 @@ Glib::ustring Field::sql_find(const Gnome::Gda::Value& value) const
   }
 }
 
-Glib::ustring Field::sql_find_operator() const
+Gnome::Gda::SqlOperatorType Field::sql_find_operator() const
 {
   switch(get_glom_type())
   {
@@ -406,7 +408,7 @@ Glib::ustring Field::sql_find_operator() const
       if(connection_pool && connection_pool->get_backend())
         return connection_pool->get_string_find_operator();
       else
-        return "LIKE"; // Default
+        return Gnome::Gda::SQL_OPERATOR_TYPE_LIKE; // Default
       break;
     }
     case(TYPE_DATE):
@@ -415,7 +417,7 @@ Glib::ustring Field::sql_find_operator() const
     case(TYPE_BOOLEAN):
     default:
     {
-      return "=";
+      return Gnome::Gda::SQL_OPERATOR_TYPE_EQ;
       break;
     }
   }
@@ -597,7 +599,7 @@ Field::glom_field_type Field::get_glom_type_for_gda_type(GType gda_type)
       result = iterFind->second;
     else
     {
-      // g_warning("FieldType::FieldType(GType gda_type): Invalid gda type: %d",  gda_type);
+      std::cerr << G_STRFUNC << ": Unhandled GType: " << g_type_name(gda_type) << std::endl;
     }
   }
 
@@ -640,6 +642,11 @@ void Field::init_map()
     m_map_gda_type_to_glom_type[G_TYPE_BOOLEAN] = TYPE_BOOLEAN;
     m_map_gda_type_to_glom_type[GDA_TYPE_BINARY] = TYPE_IMAGE;
 
+    //Extra conversions for GTypes that can be returned by glom_pygda_value_from_pyobject():
+    m_map_gda_type_to_glom_type[G_TYPE_DOUBLE] = TYPE_NUMERIC;
+    //TODO? m_map_gda_type_to_glom_type[GDA_TYPE_TIME] = ;
+    //TODO? m_map_gda_type_to_glom_type[GDA_TYPE_TIMESTAMP] = ;
+
     m_map_glom_type_to_gda_type[TYPE_NUMERIC] = GDA_TYPE_NUMERIC;
     m_map_glom_type_to_gda_type[TYPE_TEXT] = G_TYPE_STRING;
     m_map_glom_type_to_gda_type[TYPE_TIME] = GDA_TYPE_TIME;
