@@ -24,10 +24,13 @@
 #endif
 
 #include <glom/libglom/connectionpool.h>
-#include <giomm.h>
-#include <libgdamm.h>
+#include <giomm/init.h>
+#include <libgdamm/connection.h>
+#include <libgdamm/init.h>
 #include <iostream>
 
+#include <pygobject.h>
+
 //TODO: Remove this redefine when Python fixes the compiler error in their macro:
 // http://bugs.python.org/issue7463
 // Note that this sets a local copy of PyDateTimeAPI (in Python's datetime.h
@@ -43,8 +46,12 @@ namespace Glom
 
 void libglom_init()
 {
+  //Threading is always enabled starting from GLib 2.31.0:
+  //TODO: Just remove this when we can increase the glibmm version needed:
+#if !GLIB_CHECK_VERSION (2, 31, 0)
   if (!Glib::thread_supported())
     Glib::thread_init(0); //So we can use GMutex.
+#endif
 
   Gnome::Gda::init();
   Gio::init();
@@ -61,6 +68,10 @@ void libglom_init()
     //See https://bugzilla.gnome.org/show_bug.cgi?id=644702
     PyErr_Print();
   }
+
+  //Initialize PyGObject, so that functions such as pygobject_new() work
+  //instead of crashing.
+  pygobject_init(2, 28, 0);
 }
 
 void libglom_deinit()
