@@ -20,8 +20,11 @@
 
 #include <glom/mode_data/notebook_data.h>
 #include <libglom/data_structure/glomconversions.h>
+#include <glibmm/main.h>
 #include <glibmm/i18n.h>
 
+#include <iostream>
+
 #ifdef GLOM_ENABLE_MAEMO
 #include <hildonmm/program.h>
 #endif
