@@ -27,6 +27,8 @@
 #include <gtkmm/entry.h>
 #include <gtkmm/label.h>
 #include <gtksourceviewmm/sourceview.h>
+#include <gtkmm/treeview.h>
+#include <gtkmm/liststore.h>
 #include <glom/base_db.h>
 #include <libglom/data_structure/system_prefs.h>
 #include <libglom/connectionpool.h>
