@@ -21,10 +21,12 @@
 #ifndef DIALOG_FIELDCALCULATION_H
 #define DIALOG_FIELDCALCULATION_H
 
-#include <gtkmm.h>
+#include <gtkmm/dialog.h>
+#include <gtkmm/button.h>
+#include <gtkmm/label.h>
 #include <gtkmm/builder.h>
 #include <libglom/data_structure/field.h>
-#include "../../base_db.h"
+#include <glom/base_db.h>
 #include <gtksourceviewmm/sourceview.h>
 
 namespace Glom
@@ -36,6 +38,9 @@ class Dialog_FieldCalculation
 
 {
 public:
+  static const char* glade_id;
+  static const bool glade_developer;
+
   Dialog_FieldCalculation(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_FieldCalculation();
 
