@@ -23,6 +23,8 @@
 
 #include <glom/mode_design/layout/dialog_layout.h>
 #include <glom/mode_design/layout/treestore_layout.h>
+#include <gtkmm/frame.h>
+#include <gtkmm/spinbutton.h>
 
 namespace Glom
 {
@@ -30,6 +32,9 @@ namespace Glom
 class Dialog_Layout_Details : public Dialog_Layout
 {
 public:
+  static const char* glade_id;
+  static const bool glade_developer;
+  
   Dialog_Layout_Details(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_Layout_Details();
 
