@@ -24,6 +24,9 @@
 #include <glom/mode_design/layout/dialog_layout_list.h>
 #include <glom/utility_widgets/combo_textglade.h>
 #include <glom/mode_design/layout/combobox_relationship.h>
+#include <gtkmm/checkbutton.h>
+#include <gtkmm/radiobutton.h>
+#include <gtkmm/colorbutton.h>
 
 namespace Glom
 {
