@@ -22,10 +22,16 @@
 #include "window_print_layout_edit.h"
 #include <glom/box_db_table.h>
 #include <glom/print_layout/canvas_layout_item.h>
+#include <glom/utils_ui.h>
+#include <glom/application.h>
+#include <gtkmm/radioaction.h>
+#include <gtkmm/printsettings.h>
+#include <gtkmm/stock.h>
+#include <gtkmm/table.h>
+#include <gtkmm/printoperation.h>
 #include <libglom/data_structure/layout/layoutitem_line.h>
 #include <libglom/data_structure/layout/layoutitem_portal.h>
-#include <libglom/utils.h> //For bold_message()).
-#include <gtkmm/scrolledwindow.h>
+#include <libglom/utils.h> //For bold_message()).>
 #include <glibmm/i18n.h>
 
 #include <iostream>
