@@ -22,6 +22,7 @@
 #include <glom/utils_ui.h> //For bold_message()).
 #include <libglom/db_utils.h>
 #include <glom/application.h>
+#include <gtkmm/stock.h>
 #include <glibmm/i18n.h>
 
 #include <iostream>
@@ -288,7 +289,7 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
   bool something_changed = false;
   for(Gtk::TreeModel::iterator iter = rowStart; iter != iterAfter; ++iter)
   {
-    Glib::ustring table_name = m_AddDel.get_value_key(iter);
+    const Glib::ustring table_name = m_AddDel.get_value_key(iter);
 
     if(!table_name.empty())
     {
@@ -310,8 +311,11 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
           Gtk::MessageDialog dialog(Utils::bold_message(_("Delete Table")), true);
           dialog.set_secondary_text(strMsg);
           dialog.set_transient_for(*Application::get_application());
-          int iButtonClicked = dialog.run();
-
+          const int iButtonClicked = dialog.run();
+          
+          //Get a list of autoincrementing fields in the table:
+          const Glom::Document::type_vec_fields fields = document->get_table_fields(table_name);
+ 
           //Delete the table:
           if(iButtonClicked == Gtk::RESPONSE_OK)
           {
@@ -320,9 +324,29 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
               std::cerr << "Box_Tables::on_adddel_Delete(): DROP TABLE failed." << std::endl;
             else
             {
-              get_document()->remove_table(table_name); //Forget about it in the document too.
+              //Forget about it in the document too.
+              get_document()->remove_table(table_name);
+              
               something_changed = true;
             }
+            
+            //Remove the auto-increment rows.
+            //Otherwise it would not start at 0 if a table with the same name, and same field, is added again later.
+            for(Glom::Document::type_vec_fields::const_iterator iter = fields.begin(); iter != fields.end(); ++iter)
+            {
+              const Glom::sharedptr<const Glom::Field> field = *iter;
+              if(!field || !field->get_auto_increment())
+                continue;
+                
+              const Glib::ustring field_name = field->get_name();
+            
+              if(!field_name.empty())
+                DbUtils::remove_auto_increment(table_name, field_name);
+              else
+              {
+                std::cerr << G_STRFUNC << ": field_name is empty" << std::endl;
+              }
+            }
           }
         }
       }
