@@ -160,6 +160,13 @@ DbAddDel::DbAddDel()
 
   signal_style_changed().connect(sigc::mem_fun(*this, &DbAddDel::on_self_style_changed));
 #endif // !GLOM_ENABLE_CLIENT_ONLY
+
+  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_TreeView.get_selection();
+  if(refSelection)
+  {
+    refSelection->signal_changed().connect(
+      sigc::mem_fun(*this, &DbAddDel::on_treeview_selection_changed));
+  }
 }
 
 DbAddDel::~DbAddDel()
@@ -2013,6 +2020,13 @@ bool DbAddDel::on_treeview_column_drop(Gtk::TreeView* /* treeview */, Gtk::TreeV
   return true;
 }
 
+/* We do not let the developer resize the columns directly in the treeview
+ * because we cannot easily avoid this signal handler from being called just during the 
+ * intial size allocation.
+ * Anyway, this would be rather implicit anyway - people might not know that they are changing it in the document.
+ * The size can still be specified in the layout dialog.
+ */
+/*
 void DbAddDel::on_treeview_column_resized(int model_column_index, DbTreeViewColumnGlom* view_column)
 {
   if(!view_column)
@@ -2041,6 +2055,7 @@ void DbAddDel::on_treeview_column_resized(int model_column_index, DbTreeViewColu
   if(column_info.m_item)
       column_info.m_item->set_display_width(width);
 }
+*/
 
 void DbAddDel::on_treeview_column_clicked(int model_column_index)
 {
@@ -2224,7 +2239,8 @@ guint DbAddDel::treeview_append_column(const Glib::ustring& title, Gtk::CellRend
   pViewColumn->signal_clicked().connect(
     sigc::bind( sigc::mem_fun(*this, &DbAddDel::on_treeview_column_clicked), model_column_index) );
 
-  pViewColumn->connect_property_changed("width", sigc::bind(sigc::mem_fun(*this, &DbAddDel::on_treeview_column_resized), model_column_index, pViewColumn) );
+  // See the comment on on_treeview_column_resized():
+  //pViewColumn->connect_property_changed("width", sigc::bind(sigc::mem_fun(*this, &DbAddDel::on_treeview_column_resized), model_column_index, pViewColumn) );
   #endif //GLOM_ENABLE_MAEMO
 
   return cols_count;
@@ -2930,4 +2946,20 @@ Gtk::TreeModel::iterator DbAddDel::get_row_selected()
   return get_item_selected();
 }
 
+void DbAddDel::on_treeview_selection_changed()
+{
+  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_TreeView.get_selection();
+  if(!refSelection)
+    return;
+
+  const bool one_selected = (refSelection->count_selected_rows() > 0);
+  on_selection_changed(one_selected);
+}
+
+void DbAddDel::on_selection_changed(bool selection)
+{
+  m_refContextDelete->set_sensitive(selection);
+  m_refContextAdd->set_sensitive(selection);
+}
+
 } //namespace Glom
