@@ -306,6 +306,8 @@ protected:
   /// A common handler for the edit button, the context menu, etc.
   void do_user_requested_edit();
 
+  virtual void on_selection_changed(bool selection);
+
 private:
   virtual Gnome::Gda::Value treeview_get_key(const Gtk::TreeModel::iterator& row) const;
 
@@ -333,6 +335,7 @@ private:
 
   virtual bool on_button_press_event_Popup(GdkEventButton* event);
   virtual void on_treeview_button_press_event(GdkEventButton* event);
+  void on_treeview_selection_changed();
 
 protected:
   void on_MenuPopup_activate_Edit();
@@ -349,7 +352,8 @@ private:
   #ifndef GLOM_ENABLE_MAEMO
   virtual bool on_treeview_columnheader_button_press_event(GdkEventButton* event);
   virtual void on_treeview_column_clicked(int model_column_index);
-  void on_treeview_column_resized(int model_column_index, DbTreeViewColumnGlom* view_column);
+  //void on_treeview_column_resized(int model_column_index, DbTreeViewColumnGlom* view_column);
+
   void on_idle_row_edit();
   void on_cell_button_clicked(const Gtk::TreeModel::Path& path);
   void on_cell_layout_button_clicked(const Gtk::TreeModel::Path& path, int model_column_index);
@@ -411,7 +415,6 @@ private:
   Gtk::TreeView m_TreeView;
   #endif
 
-
   Gtk::TreeModel::ColumnRecord m_ColumnRecord;
 
   //typedef Gtk::ListStore type_model_store;
