@@ -24,8 +24,12 @@
 #include <libglom/connectionpool.h>
 #include <libglom/data_structure/glomconversions.h> //For util_build_sql
 #include <libglom/utils.h>
+#include <libglom/db_utils.h>
+#include <libgdamm/datamodel.h>
+#include <libgdamm/dataaccesswrapper.h>
+#include <libgdamm/datamodelarray.h>
 
-#include "glom/application.h"
+#include <glom/application.h>
 
 namespace Glom
 {
@@ -44,7 +48,7 @@ void DbTreeModelRow::fill_values_if_necessary(DbTreeModel& model, int row)
   //std::cout << "DbTreeModelRow::fill_values_if_necessary(): row=" << row << std::endl;
   //if(row == 1000)
   //{
-  //  std::cout << "1000" << std::endl;  
+  //  std::cout << "1000" << std::endl;
   //}
 
   if(m_values_retrieved)
@@ -54,7 +58,7 @@ void DbTreeModelRow::fill_values_if_necessary(DbTreeModel& model, int row)
   else
   {
     //std::cout << "debug: DbTreeModelRow::fill_values_if_necessary(): retrieving for row=" << row << std::endl;
-  
+
     if((row < (int)model.m_data_model_rows_count) && model.m_gda_datamodel)
     {
       Glib::RefPtr<Gnome::Gda::DataModelIter> iter = model.m_gda_datamodel->create_iter();
@@ -71,7 +75,7 @@ void DbTreeModelRow::fill_values_if_necessary(DbTreeModel& model, int row)
             m_db_values[i] = holder->get_value(); //TODO_gda: Why not just use get_value_at()?
           else
           {
-            // This is quite possible, for example for unset dates. jhs 
+            // This is quite possible, for example for unset dates. jhs
             //std::cerr << "DbTreeModelRow::fill_values_if_necessary(): NULL Gnome::Gda::Holder for field=" << i << std::endl;
           }
 
@@ -94,7 +98,7 @@ void DbTreeModelRow::fill_values_if_necessary(DbTreeModel& model, int row)
       if(m_extra)
       {
         //std::cout << "  debug: DbTreeModelRow::fill_values_if_necessary(): using default value" << std::endl;
-  
+
         //It is an extra row, added with append().
       }
       else if(!m_removed)
@@ -105,16 +109,24 @@ void DbTreeModelRow::fill_values_if_necessary(DbTreeModel& model, int row)
 
       //Create default values, if necessary, of the correct types:
       //Examine the columns in the returned DataModel:
+      const Glib::RefPtr<const Gnome::Gda::DataModel> datamodel = model.m_gda_datamodel;
       for(guint col = 0; col < model.m_data_model_columns_count; ++col)
       {
         if(m_db_values.find(col) == m_db_values.end()) //If there is not already a value in the map for this column.
         {
-          Glib::RefPtr<Gnome::Gda::Column> column = model.m_gda_datamodel->describe_column(col);
+          if(!datamodel) //though this should not happen.
+          {
+            m_db_values[col] = Gnome::Gda::Value();
+          }
+          else
+          {
+            const Glib::RefPtr<const Gnome::Gda::Column> column = datamodel->describe_column(col);
 
-          //We don't just create a Gda::Value of the column's gda type, 
-          //because we should use a NULL-type Gda::Value as the initial value for some fields:
-          const Field::glom_field_type glom_type = Field::get_glom_type_for_gda_type(column->get_g_type());
-          m_db_values[col] = Glom::Conversions::get_empty_value(glom_type);
+            //We don't just create a Gda::Value of the column's gda type,
+            //because we should use a NULL-type Gda::Value as the initial value for some fields:
+            const Field::glom_field_type glom_type = Field::get_glom_type_for_gda_type(column->get_g_type());
+            m_db_values[col] = Glom::Conversions::get_empty_value(glom_type);
+          }
         }
       }
     }
@@ -222,7 +234,7 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
   {
     m_get_records = false; //Otherwise it would not make sense.
 
-    //Use a dummy DataModel that has the same columns and types, 
+    //Use a dummy DataModel that has the same columns and types,
     //but which does not use a real database table,
     //so we can use it to add find criteria.
     Glib::RefPtr<Gnome::Gda::DataModelArray> model_array = Gnome::Gda::DataModelArray::create(m_column_fields.size());
@@ -246,8 +258,8 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
   m_gda_datamodel->append_row(); //TODO: Handle adding.
 #else
   std::auto_ptr<Glib::Error> error;
-  m_gda_datamodel->append_row(error); //TODO: Handle adding. 
-#endif  
+  m_gda_datamodel->append_row(error); //TODO: Handle adding.
+#endif
     return true;
   }
 
@@ -267,80 +279,26 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
 
   if(m_found_set.m_table_name.empty())
     std::cerr << "DEBUG: refresh_from_database(): found_set.m_table_name is empty." << std::endl;
-    
+
   if(m_connection && !m_found_set.m_table_name.empty() && m_get_records)
   {
-    const Glib::ustring sql_query = Utils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_extra_join, m_found_set.m_sort_clause, m_found_set.m_extra_group_by);
+    Glib::RefPtr<Gnome::Gda::SqlBuilder> sql_query = Utils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_extra_join, m_found_set.m_sort_clause);
     //std::cout << "  Debug: DbTreeModel::refresh_from_database():  " << sql_query << std::endl;
 
-    const Application* app = Application::get_application();
-    if(app && app->get_show_sql_debug())
-    {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-      try
-      {
-#endif //GLIBMM_EXCEPTIONS_ENABLED
-        std::cout << "Debug: DbTreeModel::refresh_from_database():  " << sql_query << std::endl;
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-      }
-      catch(const Glib::Exception& ex)
-      {
-        std::cout << "Debug: query string could not be converted to std::cout: " << ex.what() << std::endl;
-      }
-#endif //GLIBMM_EXCEPTIONS_ENABLED
-    }
-
-    Glib::RefPtr<Gnome::Gda::SqlParser> parser = m_connection->get_gda_connection()->create_parser();
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-    try
-    {
-      Glib::RefPtr<Gnome::Gda::Statement> stmt = parser->parse_string(sql_query);
-      //Specify the STATEMENT_MODEL_CURSOR, so that libgda only gets the rows that we actually use.
-      m_gda_datamodel = m_connection->get_gda_connection()->statement_execute_select(stmt, Gnome::Gda::STATEMENT_MODEL_CURSOR_FORWARD);
-      //Examine the columns in the returned DataModel:
-      /*
-      for(int col = 0; col < m_gda_datamodel->get_n_columns(); ++col)
-      {
-        Glib::RefPtr<Gnome::Gda::Column> column = m_gda_datamodel->describe_column(col);
-        std::cout << "  debug: column index=" << col << ", name=" << column->get_name() << ", type=" << g_type_name(column->get_g_type()) << std::endl;
-      }
-      */
-    }
-    catch(const Glib::Exception& ex)
-    {
-      std::cerr << "DbTreeModel::refresh_from_database(): Glib::Exception caught." << std::endl;
-      m_gda_datamodel.reset(); //So that it is 0, so we can handle it below.
-    }
-    catch(const std::exception& ex)
-    {
-      std::cerr << "DbTreeModel::refresh_from_database(): std::exception caught." << std::endl;
-      m_gda_datamodel.reset(); //So that it is 0, so we can handle it below.
-    }
-#else
-    std::auto_ptr<Glib::Error> error;
-    Glib::RefPtr<Gnome::Gda::Statement> stmt = parser->parse_string(sql_query, error);
-    m_gda_datamodel = m_connection->get_gda_connection()->statement_execute_select(stmt, Gnome::Gda::STATEMENT_MODEL_CURSOR_FORWARD, error);
-    if(error.get())
-    {
-      m_gda_datamodel.reset(); //So that it is 0, so we can handle it below.
-    }
-#endif //GLIBMM_EXCEPTIONS_ENABLED
-
-    if(app && app->get_show_sql_debug())
-      std::cout << "  Debug: DbTreeModel::refresh_from_database(): The query execution has finished." << std::endl;
+    m_gda_datamodel = DbUtils::query_execute_select(sql_query, true /* use_cursor */);
 
     if(!m_gda_datamodel)
     {
       m_data_model_rows_count = 0;
       m_data_model_columns_count = m_columns_count;
 
-      std::cerr << "DbTreeModel::refresh_from_database(): error executing SQL: " << sql_query << std::endl;
+      std::cerr << "DbTreeModel::refresh_from_database(): error executing SQL." << std::endl;
       ConnectionPool::handle_error_cerr_only();
       return false; //No records were found.
     }
     else
     {
-      // Use a DataAccessWrapper to allow random access. This is necessary
+      // If using the sqlite backed, then use a DataAccessWrapper to allow random access. This is necessary
       // since we use move_to_row() on a created iterator in
       // fill_values_if_necessary(), which does not work if the iterator
       // does not support it (for example the one for Sqlite recordsets does
@@ -349,12 +307,14 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
       // a) make this code dependent on the database backend used.
       // b) fetch rows we perhaps don't need, if only the first few rows of
       // a table are accessed.
-      // TODO_Performance: The unnecessary (for PostgreSQL) extra indirection might theoretically make this slower.
-      m_gda_datamodel = Gnome::Gda::DataAccessWrapper::create(m_gda_datamodel);
+      // See See libgda bug https://bugzilla.gnome.org/show_bug.cgi?id=660344
+      ConnectionPool* connection = ConnectionPool::get_instance();
+      if(connection && !connection->get_backend_supports_cursor())
+        m_gda_datamodel = Gnome::Gda::DataAccessWrapper::create(m_gda_datamodel);
 
       //This doesn't work with cursor-based models: const int count = m_gda_datamodel->get_n_rows();
       //because rows count is -1 until we have iterated to the last row.
-      const Glib::ustring sql_query_without_sort = Utils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_extra_join, type_sort_clause(), m_found_set.m_extra_group_by);
+      Glib::RefPtr<Gnome::Gda::SqlBuilder> sql_query_without_sort = Utils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_extra_join, type_sort_clause());
       const int count = Base_DB::count_rows_returned_by(sql_query_without_sort);
       if(count < 0)
       {
@@ -467,7 +427,7 @@ void DbTreeModel::get_value_vfunc(const TreeModel::iterator& iter, int column, G
             //const GType gtype_expected = column->get_g_type();
 
             result = row_details.get_value(const_cast<DbTreeModel&>(*this), column_sql, datamodel_row); //m_gda_datamodel->get_value_at(column_sql, datamodel_row); //dataRow.m_db_values[column];
-  
+
             /*
             if((result.get_value_type() != 0) && (result.get_value_type() != gtype_expected))
             {
@@ -484,7 +444,7 @@ void DbTreeModel::get_value_vfunc(const TreeModel::iterator& iter, int column, G
         GType debug_type = result.get_value_type();
         std::cout << "  debug: DbTreeModel::get_value_vfunc(): result value type: GType=" << debug_type << std::endl;
         if(debug_type)
-          std::cout << "    GType name=\"" << g_type_name(debug_type) << "\"" << std::endl; 
+          std::cout << "    GType name=\"" << g_type_name(debug_type) << "\"" << std::endl;
         */
 
         value_specific.set(result); //The compiler would complain if the type was wrong.
@@ -556,7 +516,7 @@ bool DbTreeModel::iter_nth_child_vfunc(const iterator& parent, int /* n */, iter
     return false;
   }
 
-  iter = iterator(); //Set is as invalid, as the TreeModel documentation says that it should be.  
+  iter = iterator(); //Set is as invalid, as the TreeModel documentation says that it should be.
   return false; //There are no children.
 }
 
@@ -650,7 +610,7 @@ bool DbTreeModel::create_iterator(const type_datamodel_row_index& datamodel_row,
   }
   else
   {
-    iter.set_stamp(m_stamp); 
+    iter.set_stamp(m_stamp);
     //Store the std::list iterator in the GtkTreeIter:
     //See also iter_next_vfunc()
 
@@ -675,7 +635,7 @@ bool DbTreeModel::get_iter_vfunc(const Path& path, iterator& iter) const
    if(sz > 1) //There are no children.
    {
      invalidate_iter(iter); //Set is as invalid, as the TreeModel documentation says that it should be.
-     return false; 
+     return false;
    }
 
    return iter_nth_root_child_vfunc(path[0], iter);
@@ -691,7 +651,7 @@ bool DbTreeModel::check_treeiter_validity(const iterator& iter) const
 {
   if(!(iter->get_model_gobject()))
     return false;
-    
+
   // Anything that modifies the model's structure should change the model's stamp,
   // so that old iters are ignored.
   return m_stamp == iter.get_stamp();
@@ -723,7 +683,7 @@ DbTreeModel::iterator DbTreeModel::append()
   ++m_count_extra_rows; //So that create_iterator() can succeed.
 
   //Create the row:
-  //datamodel_row->m_db_values.resize(m_columns_count); 
+  //datamodel_row->m_db_values.resize(m_columns_count);
 
   for(unsigned int column_number = 0; column_number < m_columns_count; ++column_number)
   {
@@ -830,7 +790,7 @@ void DbTreeModel::set_key_value(const TreeModel::iterator& iter, const DbValue&
 }
 
 DbTreeModel::DbValue DbTreeModel::get_key_value(const TreeModel::iterator& iter) const
-{   
+{
   if(check_treeiter_validity(iter))
   {
     type_datamodel_row_index datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
@@ -958,23 +918,22 @@ void DbTreeModel::get_record_counts(gulong& total, gulong& found) const
     {
       //Ask the database how many records there are in the whole table:
       //TODO: Apparently, this is very slow:
-      const Glib::ustring sql_query = "SELECT count(*) FROM \"" + m_found_set.m_table_name + "\"";
-      Glib::RefPtr<Gnome::Gda::SqlParser> parser = m_connection->get_gda_connection()->create_parser();
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
-      Glib::RefPtr<Gnome::Gda::Statement> stmt = parser->parse_string(sql_query);
-      Glib::RefPtr<Gnome::Gda::DataModel> datamodel = m_connection->get_gda_connection()->statement_execute_select(stmt);
-#else
-      std::auto_ptr<Glib::Error> error;
-      Glib::RefPtr<Gnome::Gda::Statement> stmt = parser->parse_string(sql_query, error);
-      Glib::RefPtr<Gnome::Gda::DataModel> datamodel = m_connection->get_gda_connection()->statement_execute_select(stmt, Gnome::Gda::STATEMENT_MODEL_RANDOM_ACCESS, error);
-      // Ignore error, datamodel presence is checked below
-#endif //GLIBMM_EXCEPTIONS_ENABLED
+
+      Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+        Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
+
+      const Gnome::Gda::SqlBuilder::Id id_function = builder->add_function("count", builder->add_id("*")); //TODO: Is * allowed here?
+      builder->add_field_value_id(id_function);
+
+      builder->select_add_target(m_found_set.m_table_name);
+
+      Glib::RefPtr<Gnome::Gda::DataModel> datamodel = DbUtils::query_execute_select(builder);
 
       if(datamodel)
       {
         if(datamodel->get_n_rows())
         {
-#ifdef GLIBMM_EXCEPTIONS_ENABLED        
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
           Gnome::Gda::Value value = datamodel->get_value_at(0, 0);
 #else
           std::auto_ptr<Glib::Error> value_error;
