@@ -24,8 +24,12 @@
 #include <glom/utils_ui.h>
 #include <glom/glade_utils.h>
 #include <libglom/data_structure/glomconversions.h>
-//#include <sstream> //For stringstream
-
+#include <gtkmm/filechooserdialog.h>
+#include <gtkmm/stock.h>
+#include <giomm.h>
+#include <giomm/file.h>
+#include <giomm/contenttype.h>
+#include <glibmm/convert.h>
 #include <iostream>   // for cout, endl
 
 namespace Glom
