@@ -21,16 +21,20 @@
 #ifndef GLOM_UTILITY_WIDGETS_IMAGE_GLOM_H
 #define GLOM_UTILITY_WIDGETS_IMAGE_GLOM_H
 
-#include <gtkmm.h>
+#include <gtkmm/eventbox.h>
+#include <gtkmm/image.h>
+#include <gtkmm/menu.h>
 #include <libglom/data_structure/field.h>
 #include "layoutwidgetfield.h"
 #include "dialog_image_progress.h"
 #include <gtkmm/builder.h>
+#include <gtkmm/frame.h>
+#include <gtkmm/builder.h>
 
 namespace Glom
 {
 
-class App_Glom;
+class Application;
 
 class ImageGlom
 : public Gtk::EventBox,
@@ -56,8 +60,6 @@ public:
 
   void set_read_only(bool read_only = true);
 
-  static Glib::RefPtr<Gdk::Pixbuf> scale_keeping_ratio(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf, int target_height, int target_width);
-
 private:
   void init();
 
@@ -76,7 +78,7 @@ private:
   void on_clipboard_clear();
   void on_clipboard_received_image(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf);
 
-  virtual App_Glom* get_application();
+  virtual Application* get_application();
 
   void setup_menu_usermode();
   void scale();
