@@ -1,7 +1,12 @@
+#include <gtkmm.h>
 #include <glom/import_csv/csv_parser.h>
 #include <tests/import/utils.h>
-//#include <glibmm/regex.h>
-#include <gtkmm.h>
+#include <giomm/file.h>
+#include <glibmm/convert.h>
+#include <glibmm/miscutils.h>
+#include <glibmm/regex.h>
+#include <glibmm/init.h>
+#include <giomm/init.h>
 #include <iostream>
 #include <cstdlib>
 
@@ -91,7 +96,12 @@ void connect_signals(Glom::CsvParser& parser)
 // Testcases
 int main(int argc, char* argv[])
 {
+  //Threading is always enabled starting from GLib 2.31.0:
+  //TODO: Just remove this when we can increase the glibmm version needed:
+#if !GLIB_CHECK_VERSION (2, 31, 0)
   Glib::thread_init();
+#endif
+
   Gtk::Main gtk(argc, argv);
 
   bool result = true;
